@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: djview.cpp,v 1.53 2007/11/19 12:11:37 leonb Exp $
+// $Id: djview.cpp,v 1.51 2007/11/06 13:19:11 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -140,8 +140,9 @@ usage()
 static void
 addDirectory(QStringList &dirs, QString path)
 {
-  QString dirname = QDir::cleanPath(path);
-  if (! dirs.contains(dirname))
+  QDir dir = path;
+  QString dirname = dir.canonicalPath();
+  if (dir.exists() && !dirs.contains(dirname))
     dirs << dirname;
 }
 
@@ -159,6 +160,10 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   QTranslator *djviewTrans = new QTranslator(this);
   // - determine preferred languages
   QStringList langs; 
+#ifdef Q_WS_MAC
+  langs += QSettings(".", "globalPreferences")
+    .value("AppleLanguages").toStringList();
+#endif
   QString varLanguage = ::getenv("LANGUAGE");
   if (varLanguage.size())
     langs += varLanguage.toLower().split(":", QString::SkipEmptyParts);
@@ -172,10 +177,6 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   if (varLcMessages.size())
     langs += varLcMessages;
 # endif
-#endif
-#ifdef Q_WS_MAC
-  langs += QSettings(".", "globalPreferences")
-    .value("AppleLanguages").toStringList();
 #endif
   QString qtLocale =  QLocale::system().name();
   if (qtLocale.size())
@@ -192,9 +193,9 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
   addDirectory(dirs, datadir + "/djview4");
 #endif
 #ifdef Q_WS_MAC
-  addDirectory(dirs, dirPath + "/Resources/$LANG.lproj");
-  addDirectory(dirs, dirPath + "/../Resources/$LANG.lproj");
-  addDirectory(dirs, dirPath + "/../../Resources/$LANG.lproj");
+  addDirectory(dirs, dirPath + "/Resources");
+  addDirectory(dirs, dirPath + "/../Resources");
+  addDirectory(dirs, dirPath + "/../../Resources");
 #endif
   addDirectory(dirs, dirPath + "/share/djvu/djview4");
   addDirectory(dirs, dirPath + "/share/djview4");
@@ -212,11 +213,13 @@ QDjViewApplication::QDjViewApplication(int &argc, char **argv)
     {
       foreach (QString dir, dirs)
         {
-          dir = dir.replace(QRegExp("\\$LANG(?!\\w)"),lang);
-          QDir qdir(dir);
-          if (! qtTransValid && qdir.exists())
+#ifdef Q_WS_MAC
+          if (dir.endsWith("/Resources"))
+            dir += "/" + lang + ".lproj";
+#endif
+          if (! qtTransValid)
             qtTransValid = qtTrans->load("qt_" + lang, dir, "_.-");
-          if (! djviewTransValid && qdir.exists())
+          if (! djviewTransValid)
             djviewTransValid= djviewTrans->load("djview_" + lang, dir, "_.-");
         }
       if (lang == "en") 
