@@ -4,7 +4,8 @@
 //C- Copyright (c) 2006  Leon Bottou
 //C-
 //C- This software is subject to, and may be distributed under, the
-//C- GNU General Public License. The license should have
+//C- GNU General Public License, either version 2 of the license,
+//C- or (at your option) any later version. The license should have
 //C- accompanied the software or you may obtain a copy of the license
 //C- from the Free Software Foundation at http://www.fsf.org .
 //C-
@@ -14,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjview.h,v 1.48 2007/01/03 15:57:11 leonb Exp $
+// $Id: qdjview.h,v 1.55 2007/11/04 02:42:41 leonb Exp $
 
 #ifndef QDJVIEW_H
 #define QDJVIEW_H
@@ -55,9 +56,11 @@ class QFileDialog;
 class QLabel;
 class QMenu;
 class QMenuBar;
+class QShortcut;
 class QStackedLayout;
 class QStatusBar;
 class QStringList;
+class QTimer;
 class QToolBar;
 class QToolBox;
 
@@ -120,7 +123,8 @@ public slots:
   bool  showSideBar(QString args, QStringList &errors);
   bool  showSideBar(QString args);
   void  print(void);
-  void  save(void);
+  void  saveAs(void);
+  void  exportAs(void);
   void  find(QString find = QString());
   
 signals:
@@ -180,6 +184,7 @@ protected slots:
   void performAbout(void);
   void performNew(void);
   void performOpen(void);
+  void performOpenLocation(void);
   void performInformation(void);
   void performMetadata(void);
   void performPreferences(void);
@@ -187,7 +192,14 @@ protected slots:
   void performZoom(void);
   void performSelect(bool);
   void performViewFullScreen(bool);
-
+  void performEscape();
+  void performUndo();
+  void performRedo();
+  void addRecent(QUrl);
+  void fillRecent();
+  void openRecent();
+  void clearRecent();
+  void saveUndoData();
 protected:
   // mode
   const ViewerMode   viewerMode;
@@ -201,12 +213,14 @@ protected:
   QPointer<QDjViewInfoDialog>  infoDialog;
   QPointer<QDjViewMetaDialog>  metaDialog;
   QPointer<QDjViewSaveDialog>  saveDialog;
+  QPointer<QDjViewExportDialog>  exportDialog;
   QPointer<QDjViewPrintDialog> printDialog;
   // widgets
   QLabel             *splash;
   QDjVuWidget        *widget;
   QStackedLayout     *layout;
   QMenu              *contextMenu;
+  QMenu              *recentMenu;
   QMenuBar           *menuBar;
   QStatusBar         *statusBar;
   QLabel             *pageLabel;
@@ -244,9 +258,11 @@ protected:
   // all actions
   QAction *actionNew;
   QAction *actionOpen;
+  QAction *actionOpenLocation;
   QAction *actionClose;
   QAction *actionQuit;
   QAction *actionSave;
+  QAction *actionExport;
   QAction *actionPrint;
   QAction *actionFind;
   QAction *actionFindNext;
@@ -290,6 +306,7 @@ protected:
   QAction *actionViewFullScreen;
   QAction *actionLayoutContinuous;
   QAction *actionLayoutSideBySide;
+  QShortcut *shortcutEscape;
   // permission
   bool printingAllowed;
   bool savingAllowed;
@@ -297,6 +314,26 @@ protected:
   Saved fsSavedNormal;
   Saved fsSavedFullScreen;
   Qt::WindowStates fsWindowState;
+  // undo/redo
+  class UndoRedo 
+  {
+  public:
+    UndoRedo();
+    void clear();
+    void set(QDjView *djview);
+    void apply(QDjView *djview);
+    bool changed(const QDjVuWidget *widget) const;
+  protected:
+    bool valid;
+    QPoint hotSpot;
+    QDjVuWidget::Position position;
+    int rotation;
+    int zoom;
+  };
+  UndoRedo here;
+  QTimer *undoTimer;
+  QList<UndoRedo> undoList;
+  QList<UndoRedo> redoList;
 };
 
 
