@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewsidebar.cpp,v 1.44 2007/11/25 13:39:11 leonb Exp $
+// $Id: qdjviewsidebar.cpp,v 1.42 2007/11/06 16:30:26 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -931,13 +931,10 @@ QDjViewFind::Model::data(const QModelIndex &index, int role) const
             case Qt::DisplayRole:
               return info.name;
             case Qt::ToolTipRole:
-              if (info.hits == 1)
-                return tr("1 hit");
-#if QT_VERSION >= 0x40020
-              return tr("%n hits", "qt>=4.2", info.hits);
-#else
-              return tr("%1 hits", "qt<4.2").arg(info.hits);
-#endif
+              if (info.hits <= 1)
+                return tr("%1 hit").arg(info.hits);
+              else
+                return tr("%1 hits").arg(info.hits);
             case Qt::WhatsThisRole:
               return widget->whatsThis();
             default:
@@ -1004,15 +1001,10 @@ QDjViewFind::Model::modelAdd(int pageno, int hits)
   RowInfo info;
   info.pageno = pageno;
   info.hits = hits;
-  if (hits == 1)
-    info.name = tr("Page %1 (1 hit)").arg(name);
-  else {
-#if QT_VERSION >= 0x40200
-    info.name = tr("Page %1 (%n hits)", "qt>=4.2", hits).arg(name);
-#else
-    info.name = tr("Page %1 (%2 hits)", "qt<4.2").arg(name).arg(hits);
-#endif
-  }
+  if (hits <= 1)
+    info.name = tr("Page %1 (%2 hit)").arg(name).arg(hits);
+  else
+    info.name = tr("Page %1 (%2 hits)").arg(name).arg(hits);
   int lo = modelFind(pageno);
   if (lo < pages.size() && pages[lo].pageno == pageno)
     {
